-- ###########################################################################################
-- ### Lotto - Sessionversion ################################################################
-- ###########################################################################################
-- ### Anlage der Datenbank                                                                ###
-- ### ----------------------------------------------------------------------------------- ###
-- ### Dieses Skript legt die benoetigten Datenbankobjekte an.                             ###
-- ###                                                                                     ###
-- ### ----------------------------------------------------------------------------------- ###
-- ### Sicherheitshinweis:                                                                 ###
-- ###      Ueber diese Befehlssammlung werden Datenbankobjekte angelegt, geaendert oder   ###
-- ###      geloescht. Auch koennen Inhalte hinzugefuegt, manipuliert oder entfernt        ###
-- ###      werden. In produktiven Umgebungen darf dieses Skript NICHT eingesetzt werden,  ###
-- ###      um versehentliche Auswirkungen auf sonstige Strukturen auszuschliessen.        ###
-- ###                                                                                     ###
-- ### Erstellung:                                                                         ###
-- ###      Torsten Ahlemeyer fuer arelium GmbH, www.arelium.de                            ###
-- ### ----------------------------------------------------------------------------------- ###
-- ### Aenderungsnachweis:                                                                 ###
-- ###     1.00.0	2022-07-26	Torsten Ahlemeyer                                          ###
-- ###              Initiale Erstellung mit Default-Werten                                 ###
-- ###########################################################################################



--------------------------------------------------------------------------------------------------
-- Statistiken -----------------------------------------------------------------------------------
--------------------------------------------------------------------------------------------------

-- temporaere Tabelle anlegen, um sich die Startzeit zu merken
BEGIN TRY
	DROP TABLE #Start
END TRY
BEGIN CATCH
END CATCH

CREATE TABLE #Start (StartTime DATETIME)
INSERT INTO #Start (StartTime) VALUES (GETDATE())



--------------------------------------------------------------------------------------------------
-- Nutzinhalt ------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------------------

USE [Lotto]
GO

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO


-- Wie in jeder Session bekommt auch das Lotto-Projekt ein eigenes Schema. So sind alle 
-- DB-Objekte, die zu disem projekt gehren, sofort zu erkennen und sauber von anderen 
-- Objekten anderer Sessions zu trennen.

-- Schemata
IF NOT EXISTS ( SELECT  *
                FROM    sys.schemas
                WHERE   name = N'Lotto' )
    EXEC('CREATE SCHEMA [Lotto]');
GO



DROP TABLE IF EXISTS [Lotto].[Ziehungen]
GO

-- Diese Tabelle speichert einzelne Ziehungen. Dabei wird stets 6 aus 49 gespielt, 
-- somit gibt es 6 "Pflichtzahlen". Einige Datenstze knnen zustzlich um eine 
-- optinale "Zusatzzahl" ergnzt werden
CREATE TABLE [Lotto].[Ziehungen](
	  [ID]			[bigint]	IDENTITY(1,1)		NOT NULL
	, [Datum]		[date]							NOT NULL
	, [Wochentag]	[nchar](10)						NOT NULL
	, [Zahl01]		[tinyint]						NOT NULL
	, [Zahl02]		[tinyint]						NOT NULL
	, [Zahl03]		[tinyint]						NOT NULL
	, [Zahl04]		[tinyint]						NOT NULL
	, [Zahl05]		[tinyint]						NOT NULL
	, [Zahl06]		[tinyint]						NOT NULL
	, [Zusatzzahl]	[tinyint]						NULL,
 CONSTRAINT [PK_Ziehungen] PRIMARY KEY CLUSTERED 
(
	[ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO




DROP TABLE IF EXISTS [Lotto].[Tipps]
GO

-- Diese Tabelle speichert Tipps fr die Lotterie 6 aus 49. Auch hier
-- kann optional eine "Zustazzahl" getippt werden.
CREATE TABLE [Lotto].[Tipps](
	  [ID]			[bigint]	IDENTITY(1,1)		NOT NULL
	, [Datum]		[date]							NOT NULL
	, [Wochentag]	[nchar](10)						NOT NULL
	, [Zahl01]		[tinyint]						NOT NULL
	, [Zahl02]		[tinyint]						NOT NULL
	, [Zahl03]		[tinyint]						NOT NULL
	, [Zahl04]		[tinyint]						NOT NULL
	, [Zahl05]		[tinyint]						NOT NULL
	, [Zahl06]		[tinyint]						NOT NULL
	, [Zusatzzahl]	[tinyint]						NULL,
 CONSTRAINT [PK_Tipps] PRIMARY KEY CLUSTERED 
(
	[ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO



DROP TABLE IF EXISTS [Lotto].[Auswertung]
GO

-- Hat man Tipps und Ziehungen zusmamen, kann man dise gegenseitig auswerten. Welche Tipps 
-- waren eine Niete udn welche ein Gewinn? Dabei unterscheidet man im Lotto diverse Gewinnklassen.
-- Die Aufbereitung dieser Auswertung passiert in dieser Tabelle.
CREATE TABLE [Lotto].[Auswertung](
	  [ID]				[bigint]	IDENTITY(1,1)		NOT NULL
	, [Datum]			[date]							NOT NULL
	, [Wochentag]		[nchar](10)						NOT NULL
	, [Zahl01]			[tinyint]						NOT NULL
	, [Zahl02]			[tinyint]						NOT NULL
	, [Zahl03]			[tinyint]						NOT NULL
	, [Zahl04]			[tinyint]						NOT NULL
	, [Zahl05]			[tinyint]						NOT NULL
	, [Zahl06]			[tinyint]						NOT NULL
	, [Zusatzzahl]		[tinyint]						NULL
	, [AnzahlTreffer]	[tinyint]						NOT NULL
	, [Gewinnklasse]	[nvarchar](30)					NULL,
 CONSTRAINT [PK_Auswertung] PRIMARY KEY CLUSTERED 
(
	[ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO




DROP TABLE IF EXISTS [Lotto].[Gewinnplan]
GO

-- Wurden anhand der Tipps und der tatschlichen Ziehung die Ergebnisse inklusive
-- der Gewinnklassen berechnet, gilt e snun zu ermitteln, wie hoch der Geldgewinn 
-- je erfolgreichem Spieler den ausfllt.
CREATE TABLE [Lotto].[Gewinnplan](
	  [ID]				[bigint]	IDENTITY(1,1)		NOT NULL
	, [Datum]			[date]							NOT NULL
	, [Wochentag]		[nchar](10)						NOT NULL
	, [Zahl01]			[tinyint]						NOT NULL
	, [Zahl02]			[tinyint]						NOT NULL
	, [Zahl03]			[tinyint]						NOT NULL
	, [Zahl04]			[tinyint]						NOT NULL
	, [Zahl05]			[tinyint]						NOT NULL
	, [Zahl06]			[tinyint]						NOT NULL
	, [Zusatzzahl]		[tinyint]						NULL
	, [AnzahlTreffer]	[tinyint]						NOT NULL
	, [Gewinnklasse]	[nvarchar](30)					NULL
	, [Gewinnhoehe]		[money]							NULL,
 CONSTRAINT [PK_Gewinnplan] PRIMARY KEY CLUSTERED 
(
	[ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

