-- ###########################################################################################
-- ### Lotto - Sessionversion ################################################################
-- ###########################################################################################
-- ### Anlage der Datenbank                                                                ###
-- ### ----------------------------------------------------------------------------------- ###
-- ### Dieses Skript fuellt Nachschlagetabellen und zeigt exemplarisch die Ziehung eines   ###
-- ### Spieltages.                                                                         ###
-- ### ----------------------------------------------------------------------------------- ###
-- ### Sicherheitshinweis:                                                                 ###
-- ###      Ueber diese Befehlssammlung werden Datenbankobjekte angelegt, geaendert oder   ###
-- ###      geloescht. Auch koennen Inhalte hinzugefuegt, manipuliert oder entfernt        ###
-- ###      werden. In produktiven Umgebungen darf dieses Skript NICHT eingesetzt werden,  ###
-- ###      um versehentliche Auswirkungen auf sonstige Strukturen auszuschliessen.        ###
-- ###                                                                                     ###
-- ### Erstellung:                                                                         ###
-- ###      Torsten Ahlemeyer fuer arelium GmbH, www.arelium.de                            ###
-- ### ----------------------------------------------------------------------------------- ###
-- ### Aenderungsnachweis:                                                                 ###
-- ###     1.00.0	2022-07-26	Torsten Ahlemeyer                                          ###
-- ###              Initiale Erstellung mit Default-Werten                                 ###
-- ###########################################################################################


USE [Lotto]
GO


-- 1. Anlage einer Nachschlagetabelle mit allen theoretisch denkbaren 
-- Normzahlen. Fr die Zusatzzahl wird spter eine eigene Tabelle angelegt
-- So werden diese Zahlen persistiert und mssen nicht jedesmal neu gebildet
-- (sondern nur noch abgefragt) werden.

DROP TABLE IF EXISTS [Lotto].[Normzahlen]
GO


DECLARE @Untergrenze	AS INTEGER
DECLARE @Obergrenze		AS INTEGER
SET @Untergrenze		= 1
SET @Obergrenze			= 49

;WITH [Einzelziehung] ( n ) AS (
        SELECT @Untergrenze UNION ALL
        SELECT @Untergrenze + n FROM [Einzelziehung] WHERE n < @Obergrenze )
SELECT
	[Einzelziehung].[n]					AS [Wert]
INTO [Lotto].[Normzahlen]
FROM [Einzelziehung]
GO




DROP TABLE IF EXISTS [Lotto].[Superzahlen]
GO

DECLARE @Untergrenze	AS INTEGER
DECLARE @Obergrenze		AS INTEGER
SET @Untergrenze		= 1
SET @Obergrenze			= 10

;WITH [Einzelziehung] ( n ) AS (
        SELECT @Untergrenze UNION ALL
        SELECT @Untergrenze + n FROM [Einzelziehung] WHERE n < @Obergrenze )
SELECT
	[Einzelziehung].n - 1			AS [Wert]
INTO [Lotto].[Superzahlen]
FROM [Einzelziehung]
GO



-- 2. Ermittlung von 6 UNTERSCHIEDLICHEN Gewinnzahlen
SELECT TOP(6) 
	[Wert]
FROM [Lotto].[Normzahlen]
ORDER BY NEWID()
GO


-- 3. Sortierung dieser Zahlen nach Gre
-- KEIN "Partionion" bei dem Hinzufgen der Zeilennummerierung
SELECT 
	  'Zahl0' + CONVERT(CHAR(1), ROW_NUMBER() OVER(ORDER BY [Wert] ASC)) 			AS [Ziehung]
	, [Wert]
FROM
	(
	SELECT TOP(6) *
	FROM [Lotto].[Normzahlen]
	ORDER BY NEWID()
	) AS [Innen]
ORDER BY [Innen].[Wert] ASC
GO



-- Pivotierung des Ergebnisses
SELECT  *
FROM  
(
	SELECT TOP (6)
		  'Zahl0' + CONVERT(CHAR(1), ROW_NUMBER() OVER(ORDER BY [Wert] ASC)) 			AS [Ziehung]
		, [Wert]
	FROM
		(
		SELECT TOP(6) *
		FROM [Lotto].[Normzahlen]
		ORDER BY NEWID()
		) AS [Innen]
	ORDER BY [Innen].[Wert] ASC
) AS [Quelle]  
PIVOT  
(  
  MIN([Wert])  
  FOR [Ziehung] IN ([Zahl01], [Zahl02], [Zahl03], [Zahl04], [Zahl05], [Zahl06])  
) AS PivotTable;  
GO







