-- ###########################################################################################
-- ### Lotto - Sessionversion ################################################################
-- ###########################################################################################
-- ### Dieses Skript ermittelt den aktuellen Spieltag (der ein Mittwoch oder Samstag nach  ###
-- ### der letzten Ziehung) und fhrt eine zufllige Ziehung 6 aus 49 (plus Zusatzzahl)    ###
-- ### durch.                                                                              ###
-- ### ----------------------------------------------------------------------------------- ###
-- ### Sicherheitshinweis:                                                                 ###
-- ###      Ueber diese Befehlssammlung werden Datenbankobjekte angelegt, geaendert oder   ###
-- ###      geloescht. Auch koennen Inhalte hinzugefuegt, manipuliert oder entfernt        ###
-- ###      werden. In produktiven Umgebungen darf dieses Skript NICHT eingesetzt werden,  ###
-- ###      um versehentliche Auswirkungen auf sonstige Strukturen auszuschliessen.        ###
-- ###                                                                                     ###
-- ### Erstellung:                                                                         ###
-- ###      Torsten Ahlemeyer fuer arelium GmbH, www.arelium.de                            ###
-- ### ----------------------------------------------------------------------------------- ###
-- ### Aenderungsnachweis:                                                                 ###
-- ###     1.00.0	2022-07-26	Torsten Ahlemeyer                                          ###
-- ###              Initiale Erstellung mit Default-Werten                                 ###
-- ###########################################################################################

USE [Lotto]
GO


DECLARE @DatumLetzteZiehung			AS DATE
DECLARE @WochentagLetzteZiehung		AS INTEGER
SET @DatumLetzteZiehung = ISNULL((SELECT TOP(1) [Datum] FROM [Lotto].[Ziehungen] ORDER BY [Datum] DESC), '19551005')

-- 1 = Montag
-- 2 = Dienstag
-- ...
-- 7 = Sonntag
SET @WochentagLetzteZiehung = (@@DATEFIRST + DATEPART(weekday, @DatumLetzteZiehung) - 1) % 7;
SET @WochentagLetzteZiehung = CASE WHEN @WochentagLetzteZiehung = 0 THEN 7 ELSE @WochentagLetzteZiehung END; -- Sonntag ist 0 bei der obigen Berechnung und wird auf die SQL interne Nummer umgestellt


DECLARE @DatumAktuelleZiehung		AS DATE
DECLARE @WochentagAktuelleZiehung	AS INTEGER
SELECT @DatumAktuelleZiehung = CASE @WochentagLetzteZiehung 
									WHEN 7 THEN DATEADD(DAY, 3, @DatumLetzteZiehung) 
									ELSE		DATEADD(DAY, 4, @DatumLetzteZiehung)
								END
SET @WochentagAktuelleZiehung = (@@DATEFIRST + DATEPART(weekday, @DatumAktuelleZiehung) - 1) % 7;
SET @WochentagAktuelleZiehung = CASE WHEN @WochentagAktuelleZiehung = 0 THEN 7 ELSE @WochentagAktuelleZiehung END; -- Sonntag ist 0 bei der obigen Berechnung und wird auf die SQL interne Nummer umgestellt

--INSERT INTO [Lotto].[Ziehungen]
--           (
--             [Datum]
--           , [Wochentag]
--           , [Zahl01]
--           , [Zahl02]
--           , [Zahl03]
--           , [Zahl04]
--           , [Zahl05]
--           , [Zahl06]
--           , [Zusatzzahl])
SELECT 
	  @DatumAktuelleZiehung				AS [Datum]
	, CASE @WochentagAktuelleZiehung
			WHEN 3 THEN 'Mittwoch'
			WHEN 7 THEN 'Sonntag'
			ELSE 'Fehler'
		END								AS [Wochentag]
	, [Rechts].[Zahl01]					AS [Zahl01]					
	, [Rechts].[Zahl02]					AS [Zahl02]
	, [Rechts].[Zahl03]					AS [Zahl03]
	, [Rechts].[Zahl04]					AS [Zahl04]
	, [Rechts].[Zahl05]					AS [Zahl05]
	, [Rechts].[Zahl06]					AS [Zahl06]
	, [Rechts].[Superzahl]				AS [Superzahl]
FROM 
	(SELECT
		TOP (1)
		[Zahl01], [Zahl02], [Zahl03], [Zahl04], [Zahl05], [Zahl06], [Superzahl]
	FROM [Lotto].[Moeglichkeiten]
	ORDER BY NEWID()
	) AS [RECHTS]
GO
 
