USE [Lotto]
GO


-- finde den Datensatz mit der niedrigsten (normalen) Zahlenkombination 
-- (sprich ohne Zusatzzahl). Dazu werden einfach alle Zahlen eines Spieltages 
-- aufaddiert und es wird nach diesem Wert sortiert.
SELECT TOP (1)
	  'niedrigste Kombination'													AS [Auswahl]
	, [Datum]																	AS [Datum]
	, [Wochentag]																AS [Wochentag]
	, [Zahl01]																	AS [Zahl01]
	, [Zahl02]																	AS [Zahl02]
	, [Zahl03]																	AS [Zahl03]
	, [Zahl04]																	AS [Zahl04]
	, [Zahl05]																	AS [Zahl05]
	, [Zahl06]																	AS [Zahl06]
	, [Zahl01] + [Zahl02] + [Zahl03] + [Zahl04] + [Zahl05] + [Zahl06]			AS [Summe]
FROM [Lotto].[Ziehungen]
ORDER BY [Zahl01] + [Zahl02] + [Zahl03] + [Zahl04] + [Zahl05] + [Zahl06] ASC, [Datum] ASC
GO



-- finde den Datensatz mit der hchsten (normalen) Zahlenkombination 
-- (sprich ohne Zusatzzahl). Dazu werden einfach alle Zahlen eines Spieltages 
-- aufaddiert und es wird nach diesem Wert sortiert.
SELECT TOP (1)
	  'hchste Kombination'														AS [Auswahl]
	, [Datum]																	AS [Datum]
	, [Wochentag]																AS [Wochentag]
	, [Zahl01]																	AS [Zahl01]
	, [Zahl02]																	AS [Zahl02]
	, [Zahl03]																	AS [Zahl03]
	, [Zahl04]																	AS [Zahl04]
	, [Zahl05]																	AS [Zahl05]
	, [Zahl06]																	AS [Zahl06]
	, [Zahl01] + [Zahl02] + [Zahl03] + [Zahl04] + [Zahl05] + [Zahl06]			AS [Summe]
FROM [Lotto].[Ziehungen]
ORDER BY [Zahl01] + [Zahl02] + [Zahl03] + [Zahl04] + [Zahl05] + [Zahl06] DESC, [Datum] ASC
GO






-- finde die beiden Zahlen, die in Kombination am hufigsten gezogen (also "wenn A gezogen
-- wird, dann wird signifikant fter B gezogen als jede andere Zahl)
SELECT 
	  [Links].[Wert]					AS [Zahl1]
	, [Rechts].[Wert]					AS [Zahl2]
	, COUNT(*)							AS [Anzahl]
FROM [Lotto].[Normzahlen] AS [Links]
INNER JOIN [Lotto].[Normzahlen] AS [Rechts] 
	ON [Links].[Wert] < [Rechts].[Wert]
LEFT JOIN [Lotto].[Ziehungen] AS [Ziehung]
	ON 1 = 1
		AND (
					[Links].[Wert]	= [Ziehung].[Zahl01]
				OR	[Links].[Wert]	= [Ziehung].[Zahl02]
				OR	[Links].[Wert]	= [Ziehung].[Zahl03]
				OR	[Links].[Wert]	= [Ziehung].[Zahl04]
				OR	[Links].[Wert]	= [Ziehung].[Zahl05]
				OR	[Links].[Wert]	= [Ziehung].[Zahl06]
			)
		AND (
					[Rechts].[Wert] = [Ziehung].[Zahl01]
				OR	[Rechts].[Wert] = [Ziehung].[Zahl02]
				OR	[Rechts].[Wert] = [Ziehung].[Zahl03]
				OR	[Rechts].[Wert] = [Ziehung].[Zahl04]
				OR	[Rechts].[Wert] = [Ziehung].[Zahl05]
				OR	[Rechts].[Wert] = [Ziehung].[Zahl06]
			)
GROUP BY [Links].[Wert], [Rechts].[Wert] 
ORDER BY COUNT(*) DESC, [Links].[Wert] ASC, [Rechts].[Wert] ASC

GO



-- Die Zahl mit der lngsten (zeilichen) Ziehungslcke...
-- welche Zahl wurde mal gezogen und dann fr eine ganz lange Zeit nicht mehr.
SELECT 
	  [Zahl]																AS [Zahl]
	, MAX(ABS(DATEDIFF(DAY, [frhestesNeuauftreten], [Erstziehungsdatum])))	AS [Zeitraum]
FROM
	(
		SELECT 
			  [Erstziehungsdatum]													AS [Erstziehungsdatum]
			, [Zahl]																AS [Zahl]
			, MIN([Vergleichsdatum])												AS [frhestesNeuauftreten]
		FROM
			(
				SELECT 
					  [Ziehung].[Datum]												AS [Erstziehungsdatum]
					, [Ziehung].[Zahl01]											AS [Zahl]
					, [Vergleich].[Datum]											AS [Vergleichsdatum]
					, ABS(DATEDIFF(DAY, [Vergleich].[Datum], [Ziehung].[Datum]))	AS [Zeitraum]

				FROM [Lotto].[Ziehungen]											AS [Ziehung]
				INNER JOIN [Lotto].[Ziehungen]										AS [Vergleich]
					ON 
						(
							   [Ziehung].[Zahl01] = [Vergleich].[Zahl01]
							OR [Ziehung].[Zahl01] = [Vergleich].[Zahl02]
							OR [Ziehung].[Zahl01] = [Vergleich].[Zahl03]
							OR [Ziehung].[Zahl01] = [Vergleich].[Zahl04]
							OR [Ziehung].[Zahl01] = [Vergleich].[Zahl05]
							OR [Ziehung].[Zahl01] = [Vergleich].[Zahl06]
						)
						AND [Ziehung].[Datum]	 < [Vergleich].[Datum]	
			) AS ALT
		GROUP BY [Erstziehungsdatum], [Zahl]

		UNION ALL

		SELECT 
			  [Erstziehungsdatum]													AS [Erstziehungsdatum]
			, [Zahl]																AS [Zahl]
			, MIN([Vergleichsdatum])												AS [frhestesNeuauftreten]
		FROM
			(
				SELECT 
					  [Ziehung].[Datum]												AS [Erstziehungsdatum]
					, [Ziehung].[Zahl02]											AS [Zahl]
					, [Vergleich].[Datum]											AS [Vergleichsdatum]
					, ABS(DATEDIFF(DAY, [Vergleich].[Datum], [Ziehung].[Datum]))	AS [Zeitraum]

				FROM [Lotto].[Ziehungen]											AS [Ziehung]
				INNER JOIN [Lotto].[Ziehungen]										AS [Vergleich]
					ON 
						(
							   [Ziehung].[Zahl02] = [Vergleich].[Zahl01]
							OR [Ziehung].[Zahl02] = [Vergleich].[Zahl02]
							OR [Ziehung].[Zahl02] = [Vergleich].[Zahl03]
							OR [Ziehung].[Zahl02] = [Vergleich].[Zahl04]
							OR [Ziehung].[Zahl02] = [Vergleich].[Zahl05]
							OR [Ziehung].[Zahl02] = [Vergleich].[Zahl06]
						)
						AND [Ziehung].[Datum]	 < [Vergleich].[Datum]	
			) AS ALT
		GROUP BY [Erstziehungsdatum], [Zahl]


		UNION ALL

		SELECT 
			  [Erstziehungsdatum]													AS [Erstziehungsdatum]
			, [Zahl]																AS [Zahl]
			, MIN([Vergleichsdatum])												AS [frhestesNeuauftreten]
		FROM
			(
				SELECT 
					  [Ziehung].[Datum]												AS [Erstziehungsdatum]
					, [Ziehung].[Zahl03]											AS [Zahl]
					, [Vergleich].[Datum]											AS [Vergleichsdatum]
					, ABS(DATEDIFF(DAY, [Vergleich].[Datum], [Ziehung].[Datum]))	AS [Zeitraum]

				FROM [Lotto].[Ziehungen]											AS [Ziehung]
				INNER JOIN [Lotto].[Ziehungen]										AS [Vergleich]
					ON 
						(
							   [Ziehung].[Zahl03] = [Vergleich].[Zahl01]
							OR [Ziehung].[Zahl03] = [Vergleich].[Zahl02]
							OR [Ziehung].[Zahl03] = [Vergleich].[Zahl03]
							OR [Ziehung].[Zahl03] = [Vergleich].[Zahl04]
							OR [Ziehung].[Zahl03] = [Vergleich].[Zahl05]
							OR [Ziehung].[Zahl03] = [Vergleich].[Zahl06]
						)
						AND [Ziehung].[Datum]	 < [Vergleich].[Datum]	
			) AS ALT
		GROUP BY [Erstziehungsdatum], [Zahl]


		UNION ALL

		SELECT 
			  [Erstziehungsdatum]													AS [Erstziehungsdatum]
			, [Zahl]																AS [Zahl]
			, MIN([Vergleichsdatum])												AS [frhestesNeuauftreten]
		FROM
			(
				SELECT 
					  [Ziehung].[Datum]												AS [Erstziehungsdatum]
					, [Ziehung].[Zahl04]											AS [Zahl]
					, [Vergleich].[Datum]											AS [Vergleichsdatum]
					, ABS(DATEDIFF(DAY, [Vergleich].[Datum], [Ziehung].[Datum]))	AS [Zeitraum]

				FROM [Lotto].[Ziehungen]											AS [Ziehung]
				INNER JOIN [Lotto].[Ziehungen]										AS [Vergleich]
					ON 
						(
							   [Ziehung].[Zahl04] = [Vergleich].[Zahl01]
							OR [Ziehung].[Zahl04] = [Vergleich].[Zahl02]
							OR [Ziehung].[Zahl04] = [Vergleich].[Zahl03]
							OR [Ziehung].[Zahl04] = [Vergleich].[Zahl04]
							OR [Ziehung].[Zahl04] = [Vergleich].[Zahl05]
							OR [Ziehung].[Zahl04] = [Vergleich].[Zahl06]
						)
						AND [Ziehung].[Datum]	 < [Vergleich].[Datum]	
			) AS ALT
		GROUP BY [Erstziehungsdatum], [Zahl]


		UNION ALL

		SELECT 
			  [Erstziehungsdatum]													AS [Erstziehungsdatum]
			, [Zahl]																AS [Zahl]
			, MIN([Vergleichsdatum])												AS [frhestesNeuauftreten]
		FROM
			(
				SELECT 
					  [Ziehung].[Datum]												AS [Erstziehungsdatum]
					, [Ziehung].[Zahl05]											AS [Zahl]
					, [Vergleich].[Datum]											AS [Vergleichsdatum]
					, ABS(DATEDIFF(DAY, [Vergleich].[Datum], [Ziehung].[Datum]))	AS [Zeitraum]

				FROM [Lotto].[Ziehungen]											AS [Ziehung]
				INNER JOIN [Lotto].[Ziehungen]										AS [Vergleich]
					ON 
						(
							   [Ziehung].[Zahl05] = [Vergleich].[Zahl01]
							OR [Ziehung].[Zahl05] = [Vergleich].[Zahl02]
							OR [Ziehung].[Zahl05] = [Vergleich].[Zahl03]
							OR [Ziehung].[Zahl05] = [Vergleich].[Zahl04]
							OR [Ziehung].[Zahl05] = [Vergleich].[Zahl05]
							OR [Ziehung].[Zahl05] = [Vergleich].[Zahl06]
						)
						AND [Ziehung].[Datum]	 < [Vergleich].[Datum]	
			) AS ALT
		GROUP BY [Erstziehungsdatum], [Zahl]


		UNION ALL

		SELECT 
			  [Erstziehungsdatum]													AS [Erstziehungsdatum]
			, [Zahl]																AS [Zahl]
			, MIN([Vergleichsdatum])												AS [frhestesNeuauftreten]
		FROM
			(
				SELECT 
					  [Ziehung].[Datum]												AS [Erstziehungsdatum]
					, [Ziehung].[Zahl06]											AS [Zahl]
					, [Vergleich].[Datum]											AS [Vergleichsdatum]
					, ABS(DATEDIFF(DAY, [Vergleich].[Datum], [Ziehung].[Datum]))	AS [Zeitraum]

				FROM [Lotto].[Ziehungen]											AS [Ziehung]
				INNER JOIN [Lotto].[Ziehungen]										AS [Vergleich]
					ON 
						(
							   [Ziehung].[Zahl06] = [Vergleich].[Zahl01]
							OR [Ziehung].[Zahl06] = [Vergleich].[Zahl02]
							OR [Ziehung].[Zahl06] = [Vergleich].[Zahl03]
							OR [Ziehung].[Zahl06] = [Vergleich].[Zahl04]
							OR [Ziehung].[Zahl06] = [Vergleich].[Zahl05]
							OR [Ziehung].[Zahl06] = [Vergleich].[Zahl06]
						)
						AND [Ziehung].[Datum]	 < [Vergleich].[Datum]	
			) AS ALT
		GROUP BY [Erstziehungsdatum], [Zahl]
	) AS DUMMY
GROUP BY
	 [Zahl]



ORDER BY [Zeitraum] DESC, [Zahl] ASC

GO





-- Gab es (im Ergebnis, nicht in der Zugreihenfolge) identische Ziehungen?
SELECT 
	  COUNT(*)							AS [Anzahl]
	, [Zahl01], [Zahl02], [Zahl03]
	, [Zahl04], [Zahl05], [Zahl06]
FROM [Lotto].[Ziehungen]
GROUP BY
	  [Zahl01], [Zahl02], [Zahl03]
	, [Zahl04], [Zahl05], [Zahl06]
HAVING COUNT(*) > 1
